@@ -54,7 +54,7 @@ class RequestInfo:
     @cached_property
     def response_content(self):
         if self.response.content:
-            if self.response.get('content-type') == 'application/json':
+            if self.response.headers.get('content-type') == 'application/json':
                 return self._format_json(self.response.content)
         return self.response.content
 
@@ -66,6 +66,8 @@ class PatchedSession(requests.Session):
 
     def send(self, request, **kwargs):
         response = super().send(request, **kwargs)
+        if response.history:
+            response = response.history[0]
         collector.collect(RequestInfo(request, response, kwargs))
         return response
 
